=====
giraf
=====

A command line utility to access imgur.com and api for use in applications.


Supported platforms
===================

* python 2.7 / 3.4
* Linux / Windows


Features
========

* Search imgur.
* Get favorites for a user.
* Get album info or image url list.


Usage
=====

* Search::

    giraf search cat -p 2                       # search cat, get 2 pages of result
    giraf search dog -s viral -i gif -m 10      # search dog, sort by most viral, images of type gif, maximum of 10 results

* For help on commands, see:: 
  
    giraf -h


Download
========

* PyPI: http://pypi.python.org/pypi/giraf
* Source: https://github.com/amol9/giraf

